/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import java.util.Map;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;

import kieker.webgui.beans.application.ThemeSwitcherBean;

/**
 * This bean can be used for a single session of a user and stores the
 * currently used theme (look and feel) for this user. Currently the
 * default value being used is the "glass-x"-theme, if none is find within
 * the parameters of the faces context.
 * 
 * @author Nils Christian Ehmke
 * 
 * @see ThemeSwitcherBean
 */
@ManagedBean
@SessionScoped
public class CurrentThemeBean {

	/**
	 * The default theme used for all users.
	 */
	private static final String DEFAULT_THEME = "glass-x";
	/**
	 * The current theme.
	 */
	private String theme;

	/**
	 * Creates a new instance of this class.
	 */
	public CurrentThemeBean() {
		/* Get the parameters within the current context. */
		final Map<String, String> params = FacesContext.getCurrentInstance().getExternalContext().getRequestParameterMap();
		/* Try to find the default theme. */
		if (params.containsKey("theme")) {
			this.theme = params.get("theme");
		} else {
			/* Use the default theme. */
			this.theme = CurrentThemeBean.DEFAULT_THEME;
		}
	}

	/**
	 * Delivers the current theme.
	 * 
	 * @return The currently used theme.
	 */
	public final String getTheme() {
		return this.theme;
	}

	/**
	 * Sets the value of this bean.
	 * 
	 * @param theme
	 *            The new theme to be stored within this instance.
	 */
	public final void setTheme(final String theme) {
		this.theme = theme;
	}
}
